@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013 Aurimas Cernius
+ * Copyright (C) 2011-2014 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -166,9 +166,9 @@ namespace gnote {
     add_app_menu_item(APP_ACTION_NEW, 100, _("_New Note"), "app.new-note");
     add_app_menu_item(APP_ACTION_NEW, 200, _("New _Window"), "app.new-window");
     add_app_menu_item(APP_ACTION_MANAGE, 100, _("_Preferences"), "app.show-preferences");
-    add_app_menu_item(APP_ACTION_HELP, 100, _("_Help"), "app.help-contents");
-    add_app_menu_item(APP_ACTION_HELP, 200, _("_About"), "app.about");
-    add_app_menu_item(APP_ACTION_LAST, 100, _("_Quit"), "app.quit");
+    add_app_menu_item(APP_ACTION_LAST, 100, _("_Help"), "app.help-contents");
+    add_app_menu_item(APP_ACTION_LAST, 200, _("_About"), "app.about");
+    add_app_menu_item(APP_ACTION_LAST, 300, _("_Quit"), "app.quit");
   }
 
   Glib::RefPtr<Gio::Menu> ActionManager::get_app_menu() const
@@ -178,22 +178,17 @@ namespace gnote {
     int pos = 0;
     Glib::RefPtr<Gio::Menu> section = make_app_menu_section(APP_ACTION_NEW);
     if(section != 0) {
-      menu->insert_section(pos++, "", section);
+      menu->insert_section(pos++, section);
     }
 
     section = make_app_menu_section(APP_ACTION_MANAGE);
     if(section != 0) {
-      menu->insert_section(pos++, "", section);
-    }
-
-    section = make_app_menu_section(APP_ACTION_HELP);
-    if(section != 0) {
-      menu->insert_section(pos++, "", section);
+      menu->insert_section(pos++, section);
     }
 
     section = make_app_menu_section(APP_ACTION_LAST);
     if(section != 0) {
-      menu->insert_section(pos++, "", section);
+      menu->insert_section(pos++, section);
     }
 
     return menu;
