@@ -26,6 +26,7 @@
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/menu.h>
 
+#include "base/macros.hpp"
 #include "sharp/dynamicmodule.hpp"
 #include "note.hpp"
 #include "noteaddin.hpp"
@@ -53,9 +54,9 @@ public:
     }
   BacklinksNoteAddin();
 
-  virtual void initialize ();
-  virtual void shutdown ();
-  virtual void on_note_opened ();
+  virtual void initialize() override;
+  virtual void shutdown() override;
+  virtual void on_note_opened() override;
 private:
   void update_menu(Gtk::Menu *menu);
   void get_backlink_menu_items(std::list<BacklinkMenuItem*> & items);
