@@ -28,6 +28,7 @@
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/messagedialog.h>
 
+#include "base/macros.hpp"
 #include "sharp/dynamicmodule.hpp"
 #include "importaddin.hpp"
 
@@ -58,11 +59,11 @@ public:
     {
       _init_static();
     }
-  virtual void initialize();
-  virtual void shutdown();
+  virtual void initialize() override;
+  virtual void shutdown() override;
 
-  virtual bool want_to_run(gnote::NoteManager & manager);
-  virtual bool first_run(gnote::NoteManager & manager);
+  virtual bool want_to_run(gnote::NoteManager & manager) override;
+  virtual bool first_run(gnote::NoteManager & manager) override;
 
 private:
   void check_for_first_run(gnote::NoteManager & manager);
