@@ -97,6 +97,8 @@ namespace gnote {
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));// to save size/pos
     m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
                                 GDK_KEY_W, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
+    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
+                                GDK_KEY_Q, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
 
     m_window_menu_default = make_window_menu(m_window_actions_button, std::vector<Gtk::MenuItem*>());
     embed_widget(m_search_notes_widget);
@@ -694,6 +696,7 @@ namespace gnote {
     }
     Gtk::MenuItem *item = manage(new Gtk::MenuItem(_("_Close"), true));
     item->add_accelerator("activate", get_accel_group(), GDK_KEY_W, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+    item->add_accelerator("activate", get_accel_group(), GDK_KEY_Q, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     item->signal_activate().connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));
     menu->append(*item);
     menu->property_attach_widget() = button;
