@@ -33,8 +33,21 @@ bool string_ends_with(const std::string & s, const std::string & other)
   return (s.length() - s.rfind(other)) == other.length();
 }
 
+std::string string_to_lower(std::string s)
+{
+  for(std::string::size_type i = 0; i < s.size(); ++i) {
+    if(std::isalpha(s[i]) && std::isupper(s[i])) {
+      s[i] = std::tolower(s[i]);
+    }
+  }
+  return s;
+}
+
 int test_main(int /*argc*/, char ** /*argv*/)
 {
+  // force certain timezone so that time tests work
+  setenv("TZ", "Europe/London", 1);
+
   sharp::DateTime d(678901234, 67890);
 
   std::string date_string = sharp::XmlConvert::to_string(d);
@@ -69,10 +82,10 @@ int test_main(int /*argc*/, char ** /*argv*/)
 
   sharp::DateTime d6 = sharp::DateTime::from_iso8601("2009-03-24T13:34:35.2914680-04:00");
   date_string = gnote::utils::get_pretty_print_date(d6, true, false);
-  BOOST_CHECK(string_ends_with(date_string, "19:34"));
+  BOOST_CHECK(string_ends_with(date_string, "17:34"));
 
-  date_string = gnote::utils::get_pretty_print_date(d6, true, true);
-  BOOST_CHECK(string_ends_with(date_string, "7:34 pm"));
+  date_string = string_to_lower(gnote::utils::get_pretty_print_date(d6, true, true));
+  BOOST_CHECK(string_ends_with(date_string, "5:34 pm"));
 
   return 0;
 }
